package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M?T5,1@(!`0````````````(`/@`!````D!Y```````!``````````%C&````
M`````````$``.``(`$``'``;``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````'R\````````?+P`````````
M`"````````$````&`````,``````````P&````````#`8```````$`4`````
M``"@%0``````````(````````@````8````HP````````"C`8```````*,!@
M```````P`@```````#`"````````"``````````$````!````!P"````````
M'`)````````<`D```````$0`````````1``````````$`````````%#E=&0$
M````;+<```````!LMT```````&RW0```````S`````````#,``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`96>+%P0.^JY#&K=(KQ-MU=Y;0N(#````4`````(````'````P```"$``
M"`DX!@@!B0R,"%````!5````60```*;=HVO(U;)QNN.2?,2)!9!#1=7LQ+F<
M0'KP2FO8<5@<N8WQ#NK3[PZ&^9R!\]O3'0``````````````````````````
M```````````Y`P``$@````````````````````````"R````$@``````````
M``````````````"H`0``$@````````````````````````#9`P``$@``````
M``````````````````#T`P``$@````````````````````````!-`P``$@``
M``````````````````````"!`@``$@````````````````````````"]`P``
M$@`````````````````````````,````(``````````````````````````;
M````(`````````````````````````"4`0``$@``````````````````````
M```]!```$@````````````````````````!O`P``$@``````````````````
M``````!U`0``$@````````````````````````"'`0``$@``````````````
M``````````!=`P``$@`````````````````````````;`P``$@``````````
M``````````````!T`P``$@````````````````````````"8`@``$@``````
M``````````````````"&!```$@`````````````````````````S`@``$@``
M``````````````````````#^````$@`````````````````````````C`@``
M$@````````````````````````"H`P``$@````````````````````````#G
M`P``$@````````````````````````#1`0``$@``````````````````````
M``!$!```$@````````````````````````#$`P``$@``````````````````
M``````"%`P``$@````````````````````````"?`@``$@``````````````
M``````````#Q`0``$@````````````````````````!\`P``$@``````````
M```````````````\`@``$@````````````````````````"M`0``$@``````
M``````````````````#2`P``$@`````````````````````````-!```$@``
M```````````````````````P`0``$@`````````````````````````O````
M$@`````````````````````````?!```$@````````````````````````!D
M`0``$@````````````````````````#)````$@``````````````````````
M```4`P``$@````````````````````````#@`P``$@``````````````````
M``````!"`0``$@`````````````````````````T!```$@``````````````
M``````````!C`@``$@````````````````````````#M`P``$@``````````
M``````````````!P!```$@````````````````````````!1!```$@``````
M```````````````````"!```$@````````````````````````!5`@``$@``
M```````````````````````@`P``$@````````````````````````"R`0``
M$@````````````````````````"7`P``$@````````````````````````!_
M!```$@````````````````````````#+`P``$@``````````````````````
M``#M````$@`````````````````````````]````$@``````````````````
M```````M!```$@````````````````````````#8````$@``````````````
M```````````%`@``$@`````````````````````````5!```$@``````````
M``````````````",`@``$@`````````````````````````Q`P``$@``````
M``````````````````!7`0``$@````````````````````````".`P``$@``
M``````````````````````!B!```$@`````````````````````````>`0``
M$@````````````````````````!X!```$@````````````````````````"U
M`P``$@````````````````````````!*`@``$@``````````````````````
M``!/````$@````````````````````````#?`0``$@``````````````````
M``````!D````$@````````````````````````"0````$@``````````````
M``````````!8!```$@````````````````````````"O`P``$@``````````
M``````````````!Y````$@`````````````````````````,`0``$@``````
M``````````````````":!```(0`9`"#%8```````"`````````"^`0``$@``
M`!`:0`````````````````"U!```$`#Q_Z#58`````````````````"9!```
M(0`9`"#%8```````"`````````"B!```$`#Q_Q#%8`````````````````"8
M!```$0`9`"#%8```````"`````````!Q`@``$@```/`;0```````````````
M``"I!```$`#Q_Q#%8`````````````````!>````$@`+`&@90```````````
M``````!1`0``$@`.`)A80`````````````````"A````$@`````<0```````
M``````````"J`@``$0`9`##%8```````$P``````````;&EB<&5R;"YS;P!?
M7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%!E<FQ?<WES7W1E
M<FT`4&5R;%])<W1A=&)U9E]P='(`4&5R;%]S>7-?:6YI=#,`7VEN:70`4&5R
M;%])97AI=%]F;&%G<U]P='(`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L
M7TEC;VUP8W9?<'1R`%!E<FQ?871F;W)K7VQO8VL`4&5R;%])8W5R<W1A8VMI
M;F9O7W!T<@!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X=`!0
M97)L7TEP87)S97)?<'1R`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA
M9W,`4&5R;%])=&]P7V5N=E]P='(`4&5R;%])=&%I;G1E9%]P='(`4&5R;%]S
M=E]S971P=FX`7V9I;FD`4&5R;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`
M4&5R;%]):6Y?979A;%]P='(`4&5R;%]);W!?<'1R`%!E<FQ?265V86Q?<F]O
M=%]P='(`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C
M:P!097)L7W-V7W-E='!V`%!E<FQ?1W1H<E]K97E?<'1R`%!E<FQ?1V1O7W5N
M9'5M<%]P='(`4&5R;%])<&5R;%]D97-T<G5C=%]L979E;%]P='(`4&5R;%]G
M=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P
M97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E
M<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M
M;W)Y7W=R87``;&EB<F5S;VQV+G-O+C(`;&EB;G-L+G-O+C$`;&EB9&PN<V\N
M,@!L:6)M+G-O+C8`;&EB8W)Y<'0N<V\N,0!L:6)U=&EL+G-O+C$`;&EB<'1H
M<F5A9"YS;RXP`&]P96XV-`!R96%D`%]?97)R;F]?;&]C871I;VX`;'-E96LV
M-`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&QI8F,N<V\N-@!?7W)E9VES
M=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``9V5T<'=U:60`8VQO
M<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M
M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I
M<@!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X
M<W1A=#8T`%]?8W1Y<&5?8E]L;V,`9V5T=6ED`')E861L:6YK`&5X96-V<`!?
M7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7W-P<FEN=&9?8VAK`&UE
M;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER
M;VX`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`+W5S<B]L:6(V-"]P97)L-2]#
M3U)%`$=,24)#7S(N-`!'3$E"0U\R+C,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXS
M+C0`1TQ)0D-?,BXR+C4````"```````#``0``@````,``````````P`#````
M```%``(``P`#``,``````````P`#````!``#``,```````,````#``,``P``
M````!@```````@`#`````P````,``P`#``,````"````!P`#``,```````,`
M``````,````"`````P`$`````P`#```````````````#``,```````,````!
M``,``0`#`````0`!``$```````$`!0!3`P``$````&`````4:6D-```'`-`$
M```0````$VEI#0``!@#:!```$````'(9:0D```4`Y`0``!````!T&6D)```$
M`/`$```0````=1II"0```P#\!`````````$``0`$`P``$`````````!U&FD)
M```"`/P$````````6,)@```````&````"0``````````````(,5@```````%
M````50``````````````,,5@```````%````6P``````````````>,)@````
M```'`````0``````````````@,)@```````'`````@``````````````B,)@
M```````'`````P``````````````D,)@```````'````!```````````````
MF,)@```````'````!0``````````````H,)@```````'````!@``````````
M````J,)@```````'````!P``````````````L,)@```````'````"```````
M````````N,)@```````'````40``````````````P,)@```````'````"P``
M````````````R,)@```````'````#```````````````T,)@```````'````
M#0``````````````V,)@```````'````#@``````````````X,)@```````'
M````#P``````````````Z,)@```````'````$```````````````\,)@````
M```'````$0``````````````^,)@```````'````$@```````````````,-@
M```````'````$P``````````````",-@```````'````%```````````````
M$,-@```````'````%0``````````````&,-@```````'````%@``````````
M````(,-@```````'````%P``````````````*,-@```````'````&```````
M````````,,-@```````'````&0``````````````.,-@```````'````&@``
M````````````0,-@```````'````&P``````````````2,-@```````'````
M'```````````````4,-@```````'````'0``````````````6,-@```````'
M````'@``````````````8,-@```````'````'P``````````````:,-@````
M```'````(```````````````<,-@```````'````(0``````````````>,-@
M```````'````(@``````````````@,-@```````'````(P``````````````
MB,-@```````'````)```````````````D,-@```````'````)0``````````
M````F,-@```````'````)@``````````````H,-@```````'````)P``````
M````````J,-@```````'````5@``````````````L,-@```````'````6@``
M````````````N,-@```````'````*```````````````P,-@```````'````
M*0``````````````R,-@```````'````*@``````````````T,-@```````'
M````*P``````````````V,-@```````'````+```````````````X,-@````
M```'````+0``````````````Z,-@```````'````+@``````````````\,-@
M```````'````+P``````````````^,-@```````'````,```````````````
M`,1@```````'````,0``````````````",1@```````'````,@``````````
M````$,1@```````'````,P``````````````&,1@```````'````-```````
M````````(,1@```````'````-0``````````````*,1@```````'````-@``
M````````````,,1@```````'````-P``````````````.,1@```````'````
M.```````````````0,1@```````'````.0``````````````2,1@```````'
M````.@``````````````4,1@```````'````.P``````````````6,1@````
M```'````/```````````````8,1@```````'````/0``````````````:,1@
M```````'````/@``````````````<,1@```````'````/P``````````````
M>,1@```````'````0```````````````@,1@```````'````00``````````
M````B,1@```````'````0@``````````````D,1@```````'````0P``````
M````````F,1@```````'````1```````````````H,1@```````'````10``
M````````````J,1@```````'````1@``````````````L,1@```````'````
M1P``````````````N,1@```````'````2```````````````P,1@```````'
M````20``````````````R,1@```````'````2@``````````````T,1@````
M```'````2P``````````````V,1@```````'````3```````````````X,1@
M```````'````30``````````````Z,1@```````'````3@``````````````
M\,1@```````'````3P``````````````2(/L".A+!0``Z-H%``#HY3X``$B#
MQ`C#_S7BJ"``_R7DJ"``#Q]``/\EXJ@@`&@`````Z>#_____)=JH(`!H`0``
M`.G0_____R72J"``:`(```#IP/____\ERJ@@`&@#````Z;#_____)<*H(`!H
M!````.F@_____R6ZJ"``:`4```#ID/____\ELJ@@`&@&````Z8#_____):JH
M(`!H!P```.EP_____R6BJ"``:`@```#I8/____\EFJ@@`&@)````Z5#_____
M)9*H(`!H"@```.E`_____R6*J"``:`L```#I,/____\E@J@@`&@,````Z2#_
M____)7JH(`!H#0```.D0_____R5RJ"``:`X```#I`/____\E:J@@`&@/````
MZ?#^____)6*H(`!H$````.G@_O___R5:J"``:!$```#IT/[___\E4J@@`&@2
M````Z<#^____)4JH(`!H$P```.FP_O___R5"J"``:!0```#IH/[___\E.J@@
M`&@5````Z9#^____)3*H(`!H%@```.F`_O___R4JJ"``:!<```#I</[___\E
M(J@@`&@8````Z6#^____)1JH(`!H&0```.E0_O___R42J"``:!H```#I0/[_
M__\E"J@@`&@;````Z3#^____)0*H(`!H'````.D@_O___R7ZIR``:!T```#I
M$/[___\E\J<@`&@>````Z0#^____)>JG(`!H'P```.GP_?___R7BIR``:"``
M``#IX/W___\EVJ<@`&@A````Z=#]____)=*G(`!H(@```.G`_?___R7*IR``
M:",```#IL/W___\EPJ<@`&@D````Z:#]____);JG(`!H)0```.F0_?___R6R
MIR``:"8```#I@/W___\EJJ<@`&@G````Z7#]____):*G(`!H*````.E@_?__
M_R6:IR``:"D```#I4/W___\EDJ<@`&@J````Z4#]____)8JG(`!H*P```.DP
M_?___R6"IR``:"P```#I(/W___\E>J<@`&@M````Z1#]____)7*G(`!H+@``
M`.D`_?___R5JIR``:"\```#I\/S___\E8J<@`&@P````Z>#\____)5JG(`!H
M,0```.G0_/___R52IR``:#(```#IP/S___\E2J<@`&@S````Z;#\____)4*G
M(`!H-````.F@_/___R4ZIR``:#4```#ID/S___\E,J<@`&@V````Z8#\____
M)2JG(`!H-P```.EP_/___R4BIR``:#@```#I8/S___\E&J<@`&@Y````Z5#\
M____)1*G(`!H.@```.E`_/___R4*IR``:#L```#I,/S___\E`J<@`&@\````
MZ2#\____)?JF(`!H/0```.D0_/___R7RIB``:#X```#I`/S___\EZJ8@`&@_
M````Z?#[____)>*F(`!H0````.G@^____R7:IB``:$$```#IT/O___\ETJ8@
M`&A"````Z<#[____)<JF(`!H0P```.FP^____R7"IB``:$0```#IH/O___\E
MNJ8@`&A%````Z9#[____);*F(`!H1@```.F`^____R6JIB``:$<```#I</O_
M__\EHJ8@`&A(````Z6#[____)9JF(`!H20```.E0^____R62IB``:$H```#I
M0/O___\EBJ8@`&A+````Z3#[____)8*F(`!H3````.D@^____R5ZIB``:$T`
M``#I$/O___\E<J8@`&A.````Z0#[____)6JF(`!H3P```.GP^O__,>U)B=%>
M2(GB2(/D\%!42<?`4%A``$C'P<!70`!(Q\=P54``Z/?[___TD)!(@^P(2(L%
MD:,@`$B%P'0"_]!(@\0(PY"0D)"0D)"0D)"0D)!52(GE4TB#[`B`/5BF(```
M=4N[&,!@`$B+!5*F(`!(@>L0P&``2,'[`TB#ZP%(.=AS)&8/'T0``$B#P`%(
MB04MIB``_Q3%$,!@`$B+!1^F(`!(.=ARXL8%"Z8@``%(@\0(6\G#9F9F+@\?
MA```````2(,]R*`@``!52(GE=!*X`````$B%P'0(OR#`8`#)_^#)PY"0D)"0
MD)"0D)"0D)"005<QR4%6055!5%532(U?.$B![!`"``!(C70DB.L"D)!(BQ0+
M2(G028G02,'@"$G!X!A!@^#_)0``_P!,"<!)B=!)P>@(08'@`/\``$P)P$F)
MT$G!Z!A!@>#_````3`G`28G02<'H($B)!$Y,B<!)P>`82,'@"$&#X/\E``#_
M`$P)P$F)T$C!ZCA)P>@H08'@`/\``$P)P$@)T$B)1$X(2(/!"$B#^4`/A7/_
M__](C59H2('&:`(``.L&D)"0D)"02(M"V$@S`D@S0JA(,T*82(G!2`'`2,'I
M'T@)P8/A_TB)2AA(@\((2#GR==1,BP=(BU\@3(M/"$R+5Q!,BU\82(G:3(G`
M2`-4)(A,B<%(P>@;2,'A!4R)WD@#="202`G(3(G!@^#_2/?12(VL`IEY@EI,
MB<A,B=)(]]!,(<I,(=%,(=A("=!,B<H!Q4R)R$C!XAY(P>@"28GM2`G0@^#_
M2(G"3"'"2`G*2(GI3(VD%IEY@EI(B>I(P>$%2,'J&TR)UD@#="282`G*3(G!
M1HTD(DR)PDC!Z0)(P>(>2`G12(GJ@^'_2/?222'-2"'"3`GJ38GE2(VT%IEY
M@EI,B>))P>4%2,'J&TP)ZDV)Y8TT,DB)ZDC!Y1Y(P>H"2`GJ2`-$)*!,B>6#
MXO](]]5)(=5((<U(`TPDJ$P)[4F)]4B-K"B9>8):2(GP2<'E!4C!Z!M,">A!
MB>U"C2PH3(G@2<'D'DC!Z`))B?5,">!)B?2#X/])]]1)(<5)(=1(`U0DL$T)
M[$F)[4Z-I"&9>8):2(GI2<'E!4C!Z1M,">E)B>U&C20A2(GQ2,'F'DC!Z0)(
M"?%(B>Z#X?](]]9)(<U((<9,">Y-B>5(C;0RF7F"6DR)XDG!Y05(P>H;3`GJ
M38GEC30R2(GJ2,'E'DC!Z@)(">I(`T0DN$R)Y8/B_TCWU4DAU4@AS4@#3"3`
M3`GM28GU2(VL*)EY@EI(B?!)P>4%2,'H&TP)Z$&)[DF)]4*-+#!,B>!)P>0>
M2,'H`DP)X$F)](/@_TGWU$DAQ4DAU$@#5"3(30GL28GM3HVD(9EY@EI(B>E)
MP>4%2,'I&TP)Z4F)[4:-)"%(B?%(P>8>2,'I`D@)\4B)[H/A_TCWUDDAS4@A
MQDP)[DV)Y4B-M#*9>8):3(GB2<'E!4C!ZAM,">I-B>6--#)(B>I(P>4>2,'J
M`D@)ZD@#1"303(GE@^+_2/?522'52"'-2`-,)-A,">U)B?5(C:PHF7F"6DB)
M\$G!Y05(P>@;3`GH08GO28GU0HTL.$R)X$G!Y!Y(P>@"3`G@28GT@^#_2??4
M22'%22'42`-4).!-">Q)B>U.C:0AF7F"6DB)Z4G!Y05(P>D;3`GI28GM1HTD
M(4B)\4C!YAY(P>D"2`GQ2(GN@^'_2/?622'-2"'&3`GN38GE2(VT,IEY@EI,
MB>))P>4%2,'J&TP)ZDV)Y8TT,DB)ZDC!Y1Y(P>H"2`GJ2`-$).A,B>6#XO](
M]]5)(=5((<U(`TPD\$P)[4F)]4B-K"B9>8):2(GP2<'E!4C!Z!M,">A!B>U"
MC2PH3(G@2<'D'DC!Z`))B?5,">!)B?2#X/])]]1)(<5)(=1(`U0D^$T)[$F)
M[4Z-I"&9>8):2(GI2<'E!4C!Z1M,">E)B>U&C20A2(GQ2,'F'DC!Z0)("?%(
MB>Z#X?](]]9)(<U((<9,">Y-B>5(C;0RF7F"6DR)XDG!Y05(P>H;3`GJ38GE
MC30R2(GJ2,'E'DC!Z@)(">I(`P0D3(GE@^+_2/?522'52"'-2`-,)`A,">U)
MB?5(C:PHF7F"6DB)\$G!Y05(P>@;3`GH08GN28GU0HTL,$R)X$G!Y!Y(P>@"
M3`G@28GT@^#_2??422'%22'42`-4)!!-">Q)B>U.C:0AF7F"6DB)Z4G!Y05(
MP>D;3`GI28GM1HTD(4B)\4C!YAY(P>D"2`GQ2(GN@^'_2/?622'-2"'&3`GN
M38GE2(VT,IEY@EI,B>))P>4%2,'J&TP)ZDV)Y8TT,DB)ZDC!Y1Y(P>H"2`GJ
M2`-$)!A,B>6#XO](]]5)(=5((<U(`TPD($P)[4F)]4B-K"B9>8):2(GP2<'E
M!4C!Z!M,">A!B>])B?5"C2PX3(G@2<'D'DC!Z`),">!)B?2#X/])]]1)(<5)
M(=1(`U0D*$T)[$Z-K"&9>8):2(GI28GL2<'D!4C!Z1M,">%&C2PI2(GQ2,'F
M'DC!Z0)("?&#X?](B<Y(,<9(,>Y,C:0RH>O9;DR)ZDR)[DC!Y@5(P>H;2`GR
M1HTD(DB)ZDC!Y1Y(P>H"2`GJ@^+_2`-$)#!(B=9(,<Y(`TPD.$PQ[DB-K#"A
MZ]EN3(G@3(GF2,'F!4C!Z!M("?")[HTL,$R)Z$G!Y1Y(P>@"3`GH28GM@^#_
M2<'E!4B)QD@QUD@#5"1`3#'F2(VT,:'KV6Y(B>E(P>D;3`GIC30Q3(GA2<'D
M'DC!Z0),">%)B?6#X?])P>4%28G,23'$2`-$)$A),>Q.C:0BH>O9;DB)\DC!
MZAM,">I&C20B2(GJ2,'E'DC!Z@)(">I-B>6#XO](B=5(,<U(,?5)P>4%2`-,
M)%!(C:PHH>O9;DR)X$C!Z!M,">A!B>U"C2PH2(GP2,'F'DC!Z`)("?!)B>V#
MX/])P>4%2(G&2#'62`-4)%A,,>9(C;0QH>O9;DB)Z4C!Z1M,">F--#%,B>%)
MP>0>2,'I`DP)X4F)]8/A_TG!Y05)B<Q),<1(`T0D8$DQ[$Z-I"*AZ]EN2(GR
M2,'J&TP)ZD:-)")(B>I(P>4>2,'J`D@)ZDV)Y8/B_TG!Y05(B=5(,<U(,?5(
MC:PHH>O9;DR)X$C!Z!M,">A!B>Y(`TPD:$*-+#!(B?!(P>8>2,'H`D@)\$F)
M[8/@_TG!Y05(B<9(,=9(`U0D<$PQYDB-M#&AZ]EN2(GI2,'I&TP)Z8TT,4R)
MX4G!Y!Y(P>D"3`GA28GU@^'_2<'E!4F)S$DQQ$@#1"1X23'L3HVD(J'KV6Y(
MB?)(P>H;3`GJ1HTD(DB)ZDC!Y1Y(P>H"2`GJ38GE@^+_2<'E!4B)U4@QS4@Q
M]4B-K"BAZ]EN3(G@2,'H&TP)Z$&)[T*-+#A(B?!(P>8>2,'H`D@)\$@#C"2`
M````28GM@^#_2<'E!4B)QD@QUD@#E"2(````3#'F2(VT,:'KV6Y(B>E(P>D;
M3`GIC30Q3(GA2<'D'DC!Z0),">%)B?6#X?])P>4%28G,23'$2`.$))````!)
M,>Q.C:0BH>O9;DB)\DC!ZAM,">I&C20B2(GJ2,'E'DC!Z@)(">I-B>6#XO])
MP>4%2(G52#'-2`.,))@```!(,?5(C:PHH>O9;DR)X$C!Z!M,">A!B>U"C2PH
M2(GP2,'F'DC!Z`)("?!)B>V#X/](B<9(,=9)P>4%2`.4)*````!,,>9(C;0Q
MH>O9;DB)Z4C!Z1M,">F--#%,B>%)P>0>2,'I`DP)X4F)]8/A_TG!Y05)B<Q)
M,<1(`X0DJ````$DQ[$Z-I"*AZ]EN2(GR2,'J&TP)ZD:-)")(B>I(P>4>2,'J
M`D@)ZDV)Y8/B_TG!Y05(B=5(,<U(`XPDL````$@Q]4B-K"BAZ]EN3(G@2,'H
M&TP)Z$&)[D*-+#!(B?!(P>8>2,'H`D@)\(/@_TB)QD@QUDPQYDR-K#&AZ]EN
M2(GI2(GN2,'I&TC!Y@5(`Y0DN````$@)\4R)YDG!Y!Y(P>X"1HTL*4P)YH/F
M_TB)\4@QP4@#A"3`````2#'I3(VD"J'KV6Y,B>I,B>E(P>$%2,'J&T@)RDB)
MZ4C!Y1Y(P>D"1HTD(D@)Z8/A_TB)RD@Q\DPQZDB-K!"AZ]EN3(G@3(GB2,'B
M!4C!Z!M("=!!B>],B>I"C2PX2<'E'KC<O!N/2,'J`DP)ZDF)Q4P#K"3(````
M@^+_28G622'.28UT-0!)B=5)"<U-(>5-"?5)B>Y.C2PN2(GN2<'F!4C![AM,
M"?9&C2PN3(GF2<'D'DC![@),">9)B<1,`Z0DT````(/F_TF)]DDAUDF-#`Q)
MB?1)"=1)(>Q-"?1-B>Y.C20A3(GI2<'F!4C!Z1M,"?%&C20A2(GI2,'E'DC!
MZ0)(">E(B<5(`ZPDV````(/A_TF)SDDA]DB-5!4`2(G-2`GU3"'M3`GU38GF
M2(TL*DR)XDG!Y@5(P>H;3`GR08GN0HTL,DR)ZDG!Y1Y(P>H"3`GJ28G%3`.L
M).````"#XO])B=9)(<Y)C70U`$F)U4D)S4TAY4T)]4F)[DZ-+"Y(B>Y)P>8%
M2,'N&TP)]D:-+"Y,B>9)P>0>2,'N`DP)YDF)Q$P#I"3H````@^;_28GV22'6
M28T,#$F)]$D)U$DA[$T)]$V)[DZ-)"%,B>E)P>8%2,'I&TP)\4:-)"%(B>E(
MP>4>2,'I`D@)Z4B)Q4@#K"3P````@^'_28G.22'V2(U4%0!(B<U("?5,(>U,
M"?5-B>9(C2PJ3(GB2<'F!4C!ZAM,"?)!B>]"C2PZ3(GJ2<'E'DC!Z@),">I)
MB<5,`ZPD^````(/B_TF)UDF-=#4`28G520G-22'.32'E30GU28GN3HTL+DB)
M[DG!Y@5(P>X;3`GV1HTL+DR)YDG!Y!Y(P>X"3`GF28G$3`.D)``!``"#YO])
MB?9)(=9)C0P,28GT20G422'L30GT38GN3HTD(4R)Z4G!Y@5(P>D;3`GQ1HTD
M(4B)Z4C!Y1Y(P>D"2`GI2(G%2`.L)`@!``"#X?])B<Y)(?9(C505`$B)S4@)
M]4PA[4P)]4V)YDB-+"I,B>))P>8%2,'J&TP)\D&)[D*-+#),B>I)P>4>2,'J
M`DP)ZDF)Q4P#K"00`0``@^+_28G622'.28UT-0!)B=5)"<U-(>5-"?5)B>Y.
MC2PN2(GN2<'F!4C![AM,"?9&C2PN3(GF2<'D'DC![@),">9)B<1,`Z0D&`$`
M`(/F_TF)]DDAUDF-#`Q)B?1)"=1)(>Q-"?1-B>Y.C20A3(GI2<'F!4C!Z1M,
M"?%&C20A2(GI2,'E'DC!Z0)(">E(B<5(`ZPD(`$``(/A_TF)SDDA]DB-5!4`
M2(G-2`GU3"'M3`GU38GF2(TL*DR)XDG!Y@5(P>H;3`GR08GO0HTL.DR)ZDG!
MY1Y(P>H"3`GJ28G%3`.L)"@!``"#XO])B=9)(<Y)C70U`$F)U4D)S4TAY4T)
M]4F)[DZ-+"Y(B>Y)P>8%2,'N&TP)]D:-+"Y,B>9)P>0>2,'N`DP)YDF)Q$P#
MI"0P`0``@^;_28GV22'628T,#$F)]$D)U$DA[$T)]$V)[DZ-)"%,B>E)P>8%
M2,'I&TP)\4:-)"%(B>E(P>4>2,'I`D@)Z4B)Q4@#K"0X`0``@^'_28G.22'V
M2(U4%0!(B<U("?5,(>U,"?5-B>9(C2PJ3(GB2<'F!4C!ZAM,"?)!B>Y"C2PR
M3(GJ2<'E'DC!Z@),">I)B<5,`ZPD0`$``(/B_TF)UDDASDF-=#4`28G520G-
M32'E30GU28GN3HTL+DB)[DG!Y@5(P>X;3`GV1HTL+DR)YDG!Y!Y(P>X"3`GF
M28G$3`.D)$@!``"#YO])B?9)(=9)C0P,28GT20G422'L30GT38GN3HTD(4R)
MZ4G!Y@5(P>D;3`GQ1HTD(4B)Z4C!Y1Y(P>D"2`GI2(G%2`.L)%`!``"#X?])
MB<Y(C505`$B)S4@)]4DA]DPA[4P)]4V)YDB-+"I,B>))P>8%2,'J&TP)\D&)
M[T*-+#I,B>I)P>4>2,'J`DP)ZDF)Q4P#K"18`0``@^+_2`.$)&`!``!)B=9)
M(<Y)C70U`$F)U4D)S4B-#`A-(>5-"?5)B>Y.C2PN2(GN2<'F!4C![AM,"?9&
MC2PN3(GF2<'D'DC![@),">:#YO](B?!)B?1("=!)(=1((>A,">!)B>Q(P>4>
M3(TT`4R)Z$R)Z4C!X05(P>@;2<'L`D@)R$D)[$:--#"XUL%BRD&#Y/](B<%(
M`XPD:`$``$R)]4C!Y05(C1013(GA2#'Q3#'I2(T,"DR)\DC!ZAM(">I,B>U)
MP>4>1(T\"DB)PD@#E"1P`0``2,'M`DP)[4R)^8/E_TC!X05(C30R2(GJ3#'B
M3#'R3(TL%DR)^DC!ZAM("<I,B?%)P>8>1HTL*DB)PD@#E"1X`0``2,'I`DP)
M\4R)[H/A_TC!Y@5.C20B2(G*2#'J3#'Z20'43(GJ2,'J&T@)\DB)QD:-)"),
MB?I)P><>2,'J`DP)^DV)YH/B_T@#M"2``0``2<'F!4B-+"Y(B=9(,<Y,,>Y(
M`?5,B>9(P>X;3`GV08GN0HTL-DR)[DG!Y1Y(P>X"3`GN28G%3`.L)(@!``"#
MYO])B>Y)P>8%28U,#0!)B?5),=5-,>5.C2PI2(GI2,'I&TP)\4:-+"E,B>%)
MP>0>2,'I`DP)X4F)Q$P#I"20`0``@^'_38GN2<'F!4F-%!1)B<Q),?1),>Q.
MC20B3(GJ2,'J&TP)\D:-)")(B>I(P>4>2,'J`D@)ZDB)Q4@#K"28`0``@^+_
M38GF2(UT-0!(B=5(,<U,,>U)P>8%2(TL+DR)YDC![AM,"?9!B>]"C2P^3(GN
M2<'E'DC![@),">Y)B<5,`ZPDH`$``(/F_TF)[DG!Y@5)C4P-`$F)]4DQU4TQ
MY4Z-+"E(B>E(P>D;3`GQ1HTL*4R)X4G!Y!Y(P>D"3`GA28G$3`.D)*@!``"#
MX?]-B>Y)P>8%28T4%$F)S$DQ]$DQ[$Z-)"),B>I(P>H;3`GR1HTD(DB)ZDC!
MY1Y(P>H"2`GJ2(G%2`.L)+`!``"#XO]-B>9)P>8%2(UT-0!(B=5(,<U,,>U(
MC2PN3(GF2,'N&TP)]D&)[D*-+#9,B>Y)P>4>2,'N`DP)[DF)Q4P#K"2X`0``
M@^;_28GN2<'F!4F-3`T`28GU23'533'E3HTL*4B)Z4C!Z1M,"?%&C2PI3(GA
M2<'D'DC!Z0),">%)B<1,`Z0DP`$``(/A_TV)[DG!Y@5)C10428G,23'T23'L
M3HTD(DR)ZDC!ZAM,"?)&C20B2(GJ2,'E'DC!Z@)(">I(B<5(`ZPDR`$``(/B
M_TV)YDG!Y@5(C70U`$B)U4@QS4PQ[4B-+"Y,B>9(P>X;3`GV08GO0HTL/DR)
M[DG!Y1Y(P>X"3`GN28G%3`.L)-`!``"#YO])B>Y)P>8%28U,#0!)B?5),=5-
M,>5.C2PI2(GI2,'I&TP)\4:-+"E,B>%)P>0>2,'I`DP)X4F)Q$P#I"38`0``
M@^'_38GN2<'F!4F-%!1)B<Q),?1),>Q.C20B3(GJ2,'J&TP)\D:-)")(B>I(
MP>4>2,'J`D@)ZDB)Q4@#K"3@`0``@^+_38GF2<'F!4B-=#4`2(G52#'-3#'M
M2(TL+DR)YDC![AM,"?9!B>Y"C2PV3(GN2<'E'DC![@),">Y)B<5,`ZPDZ`$`
M`(/F_TF)[DF-3`T`28GU23'52<'F!4TQY4Z-+"E(B>E(P>D;3`GQ1HTL*4R)
MX4G!Y!Y(P>D"3`GA28G$3`.D)/`!``"#X?]-B>Y)P>8%28T4%$F)S$DQ]$DQ
M[$Z-)"),B>I(P>H;3`GR1HTD(DB)ZDC!Y1Y(P>H"2`GJ2(G%2`.L)/@!``"#
MXO]-B>9(`X0D``(``$G!Y@5(C70U`$B)U4@QS4B-#`A,,>U(C2PN3(GF2,'N
M&TP)]D&)[TR)Y4:--#Y,B>Y)P>4>2,'N`DC![0),">Y-B>5'C0P.@^;_2<'E
M'DB)\$P)[4@QT$0!U0':3#'@38GT1`'>2`'!3(GP2<'D!4C!Z!M,">`!R$:-
M!`!,B0=(B6\03(E/"$B)=QA(B5<@2('$$`(``%M=05Q!74%>05_#ZP.0D)!,
MB60DX$R)?"3X,<!(B5PDT$B);"3828G\3(EL).A,B70D\$B#[#A(A?])B?=U
M*4B+7"0(2(ML)!!,BV0D&$R+;"0@3(MT)"A,BWPD,$B#Q#C#ZP20D)"03(LU
M<8X@`$V%]G3+#[8'/#UT!(3`=4E%,>U)BQXQP$B%VW2S36/M3(GUZP20D)"0
M3(GJ3(GF2(G?Z*KC__^%P'4'0H`\*SUT-TB#Q0A(BUT`2(7;==HQP.EZ____
MZP&028G]28/%`4$/MD4`/#UT!(3`=>]%*>7KH>L%D)"0D)!,*?5*C40K`4C!
M_0-!B2_I0____^L"D)!(@^P8,<!(C70D#.@`____2(/$&,/K"9"0D)"0D)"0
MD%5(B?U32(/L&$B-7"0,9I`QP$B)WDB)[^C3_O__2(7`="A(8T0D#$C!X`-(
M`P6.C2``ZP20D)"02(/`"$B+$$B%TDB)4/AU\.O&2(/$&%M=P^L-D)"0D)"0
MD)"0D)"0D%4Q_U-(@^P(Z%/F__^+..B\X?__2(G'Z,3A__](BP`Q_TB+:`CH
M-N;__XLXZ)_A__](B<?H5^+__S'_#[88Z!WF__^+.(/C?^B#X?__2(G'Z$OB
M__](BP`Q_P^W0"#!X`<)V&:)10+H].7__XLXZ%WA__](B<?H9>'__TB+`#'_
M2(M8".C7Y?__BSCH0.'__S'2OIY:0`!(B<?H0>7__S'_2(E#*.BVY?__BSCH
M'^'__TB)Q^@GX?__2(L`,?](BU@(Z)GE__^+..@"X?__2(G'Z(KA__](BP`Q
M_TB)0S#H?.7__XLXZ.7@__](B<?H[>#__TB+`#'_2(M8".A?Y?__BSCHR.#_
M_TB)Q^A0Y/__,=)(@S@`="`Q_^A!Y?__BSCHJN#__TB)Q^@RY/__2(L`2(N0
MJ````$B)4S@Q_^@=Y?__BSCHAN#__TB)Q^B.X/__2(L`,?](BT`(2,=`0```
M``#H^.3__XLXZ&'@__](B<?H:>#__TB+`#'_2(M`"$C'0"``````Z-/D__^+
M..@\X/__2(G'Z$3@__](BP`Q_TB+6`CHMN3__XLXZ!_@__](B<?H5^3__TB+
M`$B)0TA(@\0(6UW#ZP>0D)"0D)"02(E<)-A(B6PDX$B)^TR)9"3H3(EL)/!,
MB70D^$B![+@```!(A?]T!8`_`'4S2(N<))````!(BZPDF````$R+I"2@````
M3(NL)*@```!,B[0DL````$B!Q+@```##ZP&0Z+OA__](A<!(B<5TP.L!D$B)
M[^A(Y/__2(7`#X3'````3(UP$P^V%;4>```/MD`3.=!U%`^V%:<>``!!.%8!
M=,_K!9"0D)"0#[85D1X``#G0#X2I````2(G?Z%'A__],B?=)B<3H1N'__T6-
M9`0"26/\Z#G@__]-B?%(B<=)B<1)B=BYTUA``$C'PO____^^`0```#'`Z#7C
M__](B>),B>:_`0```.C5XO__@_C_=!"+1"08)0#P```]`$```'1P3(GGZ#C@
M__],B>?HT.#__TB)[^B(X___2(7`#X5`____ZP60D)"0D$B)[^C0XO__2(G?
MZ!C@___IT/[__^L!D`^V!=H=``!!.$8!#X5&____#[85RAT``$$X5@(/A.[^
M___I,/___^L'D)"0D)"0D$R)Y^AH_O__ZX[K!)"0D)!5,>U32(G[,?](@^P(
MZ-[B__^+..A'WO__2(G'Z-_A__](B=Y(B<*_`0```.A/X?__A<!T"TB#Q`B)
MZ%M=PV:0,?_HJ>+__XLXZ!+>__](B<?HJN'__XM`&"4`\```/0!```!T)3'_
MZ(3B__^+..CMW?__2(G'Z(7A__^+0!@E`/```#T`H```=:M(B=^^`@```#'M
MZ!?B__^%P$`/E,5(@\0(6XGH7</K!I"0D)"0D$B)7"302(EL)-@QP$R)9"3@
M3(EL).A(B?-,B70D\$R)?"3X2(/L6(`^/4F)_`^4P$@!PTB)W^B%W___2(UT
M)!Q!B<5,B><QP.@C^O__2(7`2(G%=%M(B<?H8]___T2)ZD@YT`^"U@$``.L%
MD)"0D)`/M@-(@\,!B$4`2(/%`83`=>XQP$B+7"0H2(ML)#!,BV0D.$R+;"1`
M3(MT)$A,BWPD4$B#Q%C#ZP>0D)"0D)"03(LUB8@@`#'MOA````!)@SX`="-,
MB?#K!Y"0D)"0D)!(@\`(@\4!2(,X`'7SC74"2&/V2,'F`XL%LX@@`(7`#X3[
M````3(GWZ!/A__])B<=(B04YB"``2&/-387_N/____\/A&S___])QT3/"```
M``");"0<00^V!"2$P`^$%@$``#P]#X0.`0``3(G@ZP60A-)T#$B#P`$/MA"`
M^CUU\$4IY8GM2,'E`T&-?`4"2`,MVX<@`.A6W?__2(G"2(722(E%`+C_____
M#X0%____BU0D'$B+!;:'(`!(BQ3000^V!"2$P(@"="8\/70B28/$`>L)ZP.0
MD)`\/70300^V!"1(@\(!28/$`83`B`)UZ<8"/4B#P@'K")"0D)"0D)"0#[8#
M2(/#`8@"2(/"`83`=>_IG/[__^L(D)"0D)"0D)!(B??'!:.'(``!````Z+[<
M__])B<>X_____TV%_P^$<?[__TACS4R)]DR)_TB-%,T`````2(E,)`CH@M[_
M_TR)/0N'(`!(BTPD".G9_O__BVPD'.G=_O__3(G@Z0#___](@^P(,?_HY=__
M_XLXZ$[;__^YV5A``+KP&T``ON-80`!(B<=(@\0(Z:/?___K`9!(@^P(,?_H
MM=___XLXZ![;__](B<?HMO___S'_Z)_?__^+..@(V___0;B>6D``13')NA!0
M0`!,B<&^_UA``$B)QTB#Q`CI9MW__^L$D)"0D$B)7"3H2(EL)/`Q[4R)9"3X
M2('L."```$B-G"00$```9$B+!"4H````2(F$)!@@```QP.A(W/__0;FO6D``
M08G`N1190``QP+H!$```O@$```!(B=_HMM[__X7`>3I(BY0D&"```&1(,Q0E
M*````$B)Z'5E2(N<)"`@``!(BZPD*"```$R+I"0P(```2('$."```,/K`I"0
M2(G?N@`0``!(B>;H"-W__X7`B<-XL(U[`4AC_^@WV___2(7`2(G%=)U(8]M(
MB>9(B<=(B=KH_MS__\9$'0``ZX7H8MW__V:0Z1O____K"9"0D)"0D)"0D$%7
M059!54%428GT54B)_;\@64``4TB!["@0``!D2(L$)2@```!(B80D&!```#'`
MZ&SW__^^+P```$B)[TB)P^B\W/__2(7`=#M(B>Z_*5E``#'`Z.C[__](BY0D
M&!```&1(,Q0E*````$B)Z`^%8`$``$B!Q"@0``!;74%<05U!7D%?PTB)[^AT
MV___OC990`!,B>=!B<;HU-S__TB%P$F)QW2E3(UD)!!!O=%80`!!@\8!ZP.0
MD)!!@#\`30]$_4B%VW033(G^2(G?Z)#<__^%P`^$KP```$R)_^@@V___2&/0
M08!\%_\O=1A)C507_TB)T<8"`(/H`4B#Z@&`>?\O=.U!C00&/?\/```/CS?_
M__]!N3A90`!-B?BY3UI``+H`$```O@$```!,B><QP$B)+"3HZ-S__S'_Z$'=
M__^+..BJV/__2(G'Z$+<__],B>9(B<*_`0```.ARW/__A<!U)3'_Z!?=__^+
M..B`V/__2(G'Z!C<__^+0!@E`/```#T`@```=!TQ_[XV64``Z-W;__](A<!)
MB<</A1G____II?[__[X!````3(GGZ(_<__^%P'723(GFORE90`#H?OK__TR)
MY^@&VO__2(G%Z8;^___H>=O__^L'D)"0D)"0D`^V#TB)^(3)=!A(C5<!9I"`
M^2\/M@I(#T3"2(/"`83)=>[SP^L*D)"0D)"0D)"0D$B%_U-(B?MT)X`_`'0B
MZ-W9__](C50#_T@YTW(,ZS^02(/J`4@YTW,U@#HO=/+K);\"````Z+;8__](
MA<!T!6;'`"X`6\/K")"0D)"0D)"0@#HO=`E(@^H!2#G3<O)(.=IU%8`Z+W10
M6[\X64``Z4W9___K`Y"0D$B#Z@%(.=-S!8`Z+W3R2"G:,<!(C4H"2('Y`!``
M`'>L2(G>2(/"`;D`$```OZ#%8`#H<M?__[B@Q6``6\/K`9"_`@```.@NV/__
M2(G",<!(A=(/A'3___]FQP(N`$B)T%O#ZP20D)"02(/L.+\Z64``9$B+!"4H
M````2(E$)"@QP$B+!1`8``!(B00D2(L%#1@``$B)1"0(2(L%"1@``$B)1"00
M2(L%!1@``$B)1"08#[<%`1@``&:)1"0@,<#H=?3__S'`OT-90`#H:?3__S'`
MOTM90`#H7?3__S'`OU190`#H4?3__S'`OUM90`#H1?3__S'`OVM90`#H.?3_
M_S'`OR!90`#H+?3__S'`OW=90`#H(?3__S'`OX%90`#H%?3__S'`OXM90`#H
M"?3__S'`ORE90`#H_?/__S'`OY590`#H\?/__S'`OYY90`#HY?/__S'`OZE9
M0`#HN?/__TB%P'0/2(G&OX%90``QP.A%^/__,<"_NEE``.B9\___2(7`=`](
MB<:_S%E``#'`Z"7X__\QP+_764``Z'GS__](A<!T/$B)QK\@64``,<#H!?C_
M_S'`O@-:0`"_6UE``.CT]___2(M$)"AD2#,$)2@```!U6DB#Q#C#ZP60D)"0
MD#'`O^=90`#H+//__TB%P'072(G&OW=90``QP.BX]___Z['K!)"0D)!(C70D
M$;_X64``N0H```#SIG682(UT)!N_=UE``#'`Z(SW___KA>B5V/__ZP.0D)!(
M@^P(BP62@"``@_C_=`E(@\0(P^L"D)`QP+]W64``Z+SR__](B<(QP$B%TG0/
M#[82A-)T"#'`@/HP#Y7`B059@"``2(/$",/K!I"0D)"0D$B#[`CHA]C__XG'
MZ(#6__](B<(QP$B%TG0#2(L"2(/$",/K#)"0D)"0D)"0D)"0D$%6055!5$F)
M_%53NP]:0`!(@^Q`2,=$)!`/6D``2,=$)!@%6D``2(UL)!A(QT0D(!):0`!(
MQT0D*`A:0`!(QT0D,`U:0`!(QT0D.)Y:0`#K).L%D)"0D)!,B>9(B<?H_=;_
M_TB%P'102(M=`$B#Q0B`.P!T,3'`2(G?Z.'Q__](A<!)B<9T!8`X`'7,2(G?
M,<!,B>;H9_;__TB+70!(@\4(@#L`=<](@\1`6UU!7$%=05[#ZP.0D)!,B>?H
M`-;__TR)]TF)Q>CUU?__28U\!0+HZ]3__T&Y-EE``$F)Q4B)QTV)X+E/6D``
M2,?"_____[X!````,<!,B30DZ.#7__],B>Y(B=\QP.CS]?__Z5;____K#)"0
MD)"0D)"0D)"0D$%7059!54%455-(B?N_(%E``$B![)B!``!D2(L$)2@```!(
MB80DB($``#'`2,>$)(`````K6D``2,>$)(@````S6D``2,>$))````#16$``
M2,>$))@```">6D``2,=$)%#,64``2,=$)%C%64``2,=$)&`X6D``2,=$)&@N
M6D``2,=$)'!`6D``2,=$)'B>6D``2,>$)*`````?6D``2,>$)*@```!$6D``
M2,>$)+````">6D``Z(7P__](A<!T"8`X``^%!P,``#'`Z.#]__](A<!)B<8/
MA!P#``!!#[8N0(3M="?H]M3__TR)\NL!D$B+"$@/ONWV!&D(=0/&`E](@\(!
M#[8J0(3M=>1!O`$```"_S%E``.L<ZP60D)"0D$ECQ$&#Q`%(BWS$4(`_``^$
M,P(``#'`Z`3P__](A<!(B<5TW$B)Q^CD\___A<!TT$B)[^@8U/__2(7`28G%
M=,!,B>_H.-3__TR)]TB)Q>@MU/__B>I$C:0"!`0``$UCY$R)Y^@8T___3(GG
M2(G%2(E$)#CH"-/__T&Y.%E``$V)Z+E-6D``2,?"_____TB)QTF)Q+X!````
M,<!,B70D"$C'!"166D``Z/35__^^[0$``$R)Y^B'UO__,<"_"%I``.A;[___
M2(7`#X1B`@``2(G'Z'K3__](BSM(B<;HG_?__TB%P$F)Q0^$0P(``$R)[^B+
MT___@_@#?C9(8]"_6UI``+D%````28UT%?SSIG4@@_@$#X3_!@``@^@$2)A!
M@'P%_R\/A.X&``#K!)"0D)`QP.@)_/__A<!U%3'V3(GOZ,O3__^%P$&)QP^%
M\`$``+X#6D``OW=90``QP.A?\___Z*K2__]!N3A90`")!"1-B>"Y>5I``$C'
MPO____^^`0```$B)[S'`2,=$)`B>6D``,=OH"-7__^M,ZP20D)"0Z`O4__^#
M.!%U3NAATO__@\,!B00D0;DX64``38G@N8=:0`!(Q\+_____O@$```!(B>\Q
MP$C'1"00GEI``(E<)`CHNM3__[[M`0``2(GOZ$W5__^#^/]TJ$R)Y^APTO__
MOR!90`!(B>XQP.BQ\O__2(GOZ*G[__](BY0DB($``&1(,Q0E*````$B+1"0X
M#X6T!@``2('$F($``%M=05Q!74%>05_#ZP&02(NL)(````!!O`$```"`?0``
M=1GK0F:026/$08/$`4B+K,2`````@'T``'0K2(GOZ)/Q__^%P'3?2(GOZ,?1
M__](A<!)B<5TS^FJ_?__ZPB0D)"0D)"0D$4Q[>F8_?__ZP:0D)"0D)!(B<=(
MB40D*.@#^___2(M$)"A(B<?HAM'__TB)1"0XZ4/____K`I"0O0$```"_'UI`
M`.L$D)"0D#'`Z#'M__](A<!T%$B)Q^A4T?__2(7`28G&#X6T_/__2&/%@\4!
M2(N\Q*````"`/P!US4&^)%I``.G&_/__ZPB0D)"0D)"0D$R+*^FU_?__ZP:0
MD)"0D)!,C;0DP````+H"````2,?&[O___XG'Z!73__^Z!@```$R)]D2)_^CU
MS___@+PDP`````!U#H"\),$```!##X0#!0``3(VL),"````QTC'V1(G_NXFK
MS>_HU-+__TF-13BY_MRZF+KPX=+#2,>$),"````!(T5G2(F<),B```!(B8PD
MT(```$C'A"38@```=E0R$$B)E"3@@```2,>$).B`````````2,>$)/"`````
M````QX0D.($```````!(B40D0.L$D)"0D+H`@```3(GV1(G_Z$C/__^%P(G#
M#XZ&`0``2(N,).B```!(8\.+O"0X@0``3(GVC13!2#G*2(F4).B````/DL%(
MP>@=#[;)2`&,)/"```!(`80D\(```(7_=&6Y0````"GY2&/_.<L/3LM(`WPD
M0$ACT8E,)#!(B50D2.C8T/__BX0D.($``(M,)#`!R(/X0(F$)#B!```/A6/_
M__](BW0D2$R)[RG+28TT-DB)="0PZ*/3__](BW0D,.L$D)"0D(/[/P^.LP``
M`#'`ZP.0D)!(BQ0&3(GO2(F4)/B```!(BU0&"$B)E"0`@0``2(M4!A!(B90D
M"($``$B+5`882(F4)!"!``!(BU0&($B)E"08@0``2(M4!BA(B90D(($``$B+
M5`8P2(F4)"B!``!(BU0&.$B)1"0H2(ET)#!(B90D,($``.@/T___2(M$)"B)
MVDB+="0P2(/`0"G"@_H_#X]L____@^M`B=K!Z@:)T,'B!DC!X`8ITTB-=#!`
M2(M\)$!(8].Y2````.AJSO__B9PD.($``.EF_O__ZP20D)"01(G_Z!#-__](
MBYPDZ(```$R+M"3P@```2(G82,'H`X/@/TACT(/``8/X.,:$%/B```"`#X]P
M`@``NC@````Q]BG"2)A)C7P%.$ACTNBGS/__3(GP3(GO1(BT)#.!``!(P>@8
MB)PD-X$``$R-K"1Q@0``B(0D,($``$R)\$C!Z!"(A"0Q@0``3(GP3(VT)$"!
M``!(P>@(B(0D,H$``$B)V$C!Z!B(A"0T@0``2(G82,'H$(B$)#6!``!(B=@Q
MVTC!Z`B(A"0V@0``Z.K1__](BX0DP(```$B)PHB$)'.!``!(P>H808G0B)0D
M<($``$B)PDC!ZA"(E"1Q@0``2(G"2(N$),B```!(P>H(B)0D<H$``$B)PHB$
M)'>!``!(P>H8B)0D=($``$B)PDC!ZA"(E"1U@0``2(G"2(N$)-"```!(P>H(
MB)0D=H$``$B)PHB$)'N!``!(P>H8B)0D>($``$B)PDC!ZA"(E"1Y@0``2(G"
M2(N$)-B```!(P>H(B)0D>H$``$B)PHB$)'^!``!(P>H8B)0D?($``$B)PDC!
MZA"(E"1]@0``2(G"2(N$)."```!(P>H(B)0D?H$``$B)PHB$)(.!``!(P>H8
MB)0D@($``$B)PDC!ZA"(E"2!@0``2(G"2,'J"(B4)(*!``#K$>L&D)"0D)"0
M10^V10!)@\4!28T\'C'`10^VP+ET6D``2,?"_____[X!````2(/#`NC3SO__
M2(/[*'7-QH0D:($```!!N3A90`!-B>"Y95I``$C'PO____^^`0```$B)[S'`
M2,=$)`B>6D``3(DT).B4SO__Z>?Y___K!9"0D)"02(M;"$B%VP^$"_G__TB)
MW^A3S/__2(/X`P^&^?C__TB-=`/\OV!:0`"Y!0```/.F3`]$Z^G?^/__38U]
M.+I`````,?8IPDB828T\!TACTN@TRO__3(GOZ.S/__^Y!P```#'`3(G_\TBK
MZ7/]__^`O"3"````00^%[_K__X"\),,```!##X7A^O__@+PDQ````$@/A=/Z
M__^`O"3%````10^%Q?K__T2)_[H"````2,?&QO___^B>S?__NBD```!,B?9$
MB?_H?LK__^GT_O__Z.3,___K`I"0058Q_T%505154TB![!`0``!D2(L$)2@`
M``!(B80D"!```#'`Z.?-__^+..A0R?__2(G'Z'C+__^_6UE``,8``3'`Z.GF
M__](A<!T"8`X,0^$NP(``#'`Z"3R__\Q_^BMS?__BSCH%LG__[D+````N@$`
M``"^F%I``$B)Q^A/RO__2(7`#X2W````2(M`$#';3(M@*(L%QG0@`(/X`0^.
MDP```+T(````ZS+K!)"0D)!)BW402(L%G70@`$B+/"CH+,S__X7`=6B#PP&+
M!8]T(`!(@\4(C5,!.=!^6C'_Z"W-__^+..B6R/__,<F)VDR)YDB)Q^AGR___
M2(7`=#),BRA!]D4-!'6H,?_H`<W__XLXZ&K(__],B>ZY`@```#'22(G'Z$C-
M__](B<;KA^L!D(L%*G0@`(U0_SG:#X1O`0``,?_HR,S__XLXZ#'(__^Y!```
M`+H!````OIU:0`!(B<?H:LG__TB%P$B)PW0V2(M`$#'_2(LHZ)3,__^+..C]
MQ___NI]:0`!(B<=(B>[H;<G__TB+0Q!(BQCV0PY`#X5,`0``,?_H9<S__XLX
MZ,['__^Y!````+H!````OJ=90`!(B<?H!\G__TB%P$B)PW0[,<"_*5E``.A3
MY?__2(7`28G$#X0_`0``2(M#$#'_2(LHZ!G,__^+..B"Q___3(GB2(GN2(G'
MZ/3(__\Q_^C]R___BSCH9L?__TB)Q^B.R?__,?_&``#HY,O__XLXZ$W'__](
MB<?H]<O__[\@64``2,<``````#'`Z.+D__](A<!(B040<R``#X1S`0``ONT!
M``!(B<?HY<O__X/X$70-A<!T"8/X_P^%Q`$``$B+A"0($```9$@S!"4H````
M9I`/A:8!``!(@<00$```6UU!7$%=05[#ZPB0D)"0D)"0D(/X`0^.B/[__[L!
M````9I`Q_X/#`>A&R___BSCHK\;__TR)YDB)Q^CDQ___.1U^<B``?]SI6/[_
M_^L%D)"0D)`Q_^@9R___BSCH@L;__TB)WDB)Q^C'R?__Z9;^__]FD(!X`0`/
MA$+]___K!)"0D)#I,/W__^L!D$B+!2ER(``Q_TR+,$B+0Q!,BR#HT,K__XLX
MZ#G&__^Z_P\``$B)YK^D6D``Z/?(__^%P$&)Q7Y008U%_TACT(`\%`!U!X7`
M=#]!B<5-8^V^+P```$B)YTR)ZNAIQO__2(7`="0Q_^A]RO__BSCHYL7__TR)
MZ4B)XDR)YDB)Q^B5R/__Z5S^__\Q_^A9RO__BSCHPL7__TR)\DR)YDB)Q^@T
MQ___Z3O^__](BSV`<2``Z!/R__](B06$<2``2(M#$$B++6EQ(`!,BR!!]D0D
M#00/A(0```!)BT0D$$B)[DB)Q^@2QO__B<5(BT,02(L8]D,-!'1#2(M#$$B)
MPDB+!2UQ(`")Z;_H6D``2(LP,<#H!,G__^B?R/__B<%(BP4.<2``2(L5%W$@
M`+\86T``2(LP,<#HX,C__S'_Z*G)__^+..@2Q?__N0(````QTDB)WDB)Q^CP
MR?__ZY\Q_^B'R?__BSCH\,3__[D"````,=),B>9(B<?HSLG__^E<____ZP>0
MD)"0D)"054B)_5-(@^P(Z.+L__\/MA!(B<.$TG0:2(U``>L"D)"`^B\/MA!(
M#T382(/``832=>XQP.AG[___A<!T'4B%[708@'T``'02OE9:0`!(B=_H*\?_
M_T@YV'0'2(/$"%M=PTB#Q`A(B>];7>EAY/__D$B#[`@Q_^CER/__BSCH3L3_
M_[[_____2(G'Z#'&__\Q_^C*R/__BSCH,\3__S'2OL`W0`!(B<=(@\0(Z0#)
M__]32(/L((E\)!Q(B70D$$B-?"0<2(E4)`A(C70D$$B-5"0(Z'G(__^Z$!I`
M`+\`'$``2(G6Z/<!```Q_^BPQ?__@#@`=3;HEL7__TB%P$B)!9QO(``/A+8!
M``!(B<?H3L;__S'_Z$?(__^+..BPP___2(G'Z'C'___&```Q_^@NR/__BSCH
ME\/__TB)Q^@OR/__@`@",?_H%<C__XLXZ'[#__](B<?H%LC__X`(`8M\)!R#
MQP5(8_](A?\/B!@!``#R2`\JQ_(/6`4K!0``9@\N!2L%```/AS\!``!(P><#
MZ"S'__](BW0D$$B)!0AO(`!(BQ9(QT`(LUI``$C'0!"`6T``2,=`&+9:0`!(
MB1"+5"0<QP7D;B``!````(/Z`7XBC4K^2(T\S0@````QR6:02(M<#@A(B5P(
M($B#P0A(.?EU[8U*!$4QP(/"`[Y@/D``2&/)2,=$R/@`````2(L]C&X@`$B)
MP>@4P___A<")PW0^2(L]=VX@`.C2Q?__,<"_:UE``.A&X/__2(7`=#%(BSU:
M;B``Z*7"___HP,3__XG82(/$(%O#ZP:0D)"0D)!(BSTY;B``Z)3#__^)P^NR
M2(L]06X@`$B%_W0IZ'_]___KO.L#D)"02(GX2(GZ2-'H@^(!2`G0\D@/*L#R
M#UC`Z=#^__^_(%E``.C1W___2(7`2(G'2(D%_&T@`'2!Z[R_`0```.BVPO__
MOC#%8`"_'5E``#'`Z+7%__^0D)"0D$B-!2$!``!(A<!T#$B+#14!``#IN,+_
M_S')Z_>0D)"02(EL)-A,B60DX$B-+2]H(`!,C24H:"``3(EL).A,B70D\$R)
M?"3X2(E<)-!(@^PX3"GE08G]28GV2,']`TF)U^ACP?__2(7M=!PQVP\?0`!,
MB?I,B?9$B>]!_Q3<2(/#`4@YZW+J2(M<)`A(BVPD$$R+9"083(ML)"!,BW0D
M*$R+?"0P2(/$.,,/'X``````\\.0D)"0D)"0D)"0D)"0D%5(B>532(/L"$B+
M!9!G(`!(@_C_=!F[`,!@``\?1```2(/K"/_02(L#2(/X_W7Q2(/$"%O)PY"0
M2(/L".@_QO__2(/$",,```````````````````````````````````$``@``
M```````````````N+@`E<R\E<P!P97)L>'-I+F,`1'EN84QO861E<CHZ8F]O
M=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S
M`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!0
M15),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!
M4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!4E]!4D=6
M7S``4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U0
M1$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!
M3CT`,0!,24)0051(`$193$1?3$E"4D%265]0051(`%5315(`4UE35$5-`$,Z
M7%1%35``+W1M<`!414U01$E2`%1-4`!54T523D%-10`E<R5S)7,E<P!P87(M
M`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E,#)X`"5S)7-T96UP+25U)7,`
M)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``O<')O8R]S96QF+V5X90`M
M90`M+0``````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``
M`````````"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("T@86)O<G1I;F<@
M=VET:"`E:2X*`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('1E;7!O<F%R>2!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*````
M``````````````````#`0W!A<BYP;```(R$O=7-R+V)I;B]P97)L"F5V86P@
M)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@("`@:68@
M,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP86-K86=E(%]?
M<&%R7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M
M;V1U;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI
M;F4@,34X"@IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*
M14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER92!&:6QE
M.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(')E<75I
M<F4@1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO=FEN9R!F
M:6QE<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ9FEN9&1E
M<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M
M<"D["B`@("!R;61I<B`D<&%R7W1E;7`["B`@("`C($1O;B=T(')E;6]V92!T
M;W!D:7(@8F5C875S92!T:&ES(&-A=7-E<R!A(')A8V4@=VET:"!O=&AE<B!A
M<'!S"B`@("`C('1H870@87)E('1R>6EN9R!T;R!S=&%R="X*"B`@("!I9B`H
M+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*("`@("`@("`C
M(%-O;65T:&EN9R!W96YT('=R;VYG('5N;&EN:VEN9R!T:&4@=&5M<&]R87)Y
M(&1I<F5C=&]R>2X@(%1H:7,*("`@("`@("`C('1Y<&EC86QL>2!H87!P96YS
M(&]N('!L871F;W)M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S:&%R960*
M("`@("`@("`C(&QI8G)A<FEE<R!A;F0@97AE8W5T86)L97,@=&AA="!A<F4@
M:6X@=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG<F]U;F0*("`@("`@("`C('-H
M96QL(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R92!N;R!L;VYG97(@:6X@=7-E
M(&)Y('1H:7,@<')O8V5S<RX*("`@("`@("`C($1O;B=T(&1O(&%N>71H:6YG
M(&]N(%=I;F1O=W,@8F5C875S92!O=7(@<&%R96YT('!R;V-E<W,@=VEL;`H@
M("`@("`@(",@=&%K92!C87)E(&]F(&-L96%N:6YG('1H:6YG<R!U<"X*"B`@
M("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`H@("`@("`@("`@("!4
M14U03$%412`]/B`G=&UP6%A86%@G+`H@("`@("`@("`@("!$25(@/3X@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@("`@("`@(%-5
M1D9)6"`]/B`G+F-M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]/B`P+`H@("`@
M("`@("D["@H@("`@("`@('!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H
M:6QE(%L@7"1X("UL="`Q,"!=.R!D;PH@("!R;2`M<F8@)R1P87)?=&5M<"<*
M("`@:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"B`@("`@("!B<F5A
M:PH@("!F:0H@("!S;&5E<"`Q"B`@('@]8&5X<'(@7"1X("L@,6`*9&]N90IR
M;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*("`@("`@("`@("`@8VAM
M;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*("`@("`@("!M>2`D8VUD(#T@)'1M
M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*("`@("`@("!C
M;&]S92`D=&UP.PH@("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@("!O=71S
M*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE
M86YU<#H@*0H@("`@("`@("`@("`@+B`D=&UP+3YF:6QE;F%M92D["B`@("!]
M"GT@?0H*0D5'24X@>PH@("`@26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D
M969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*"B`@("!E=F%L('L*"E]P
M87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A
M;F0@)$5.5GM005)?05)'5E\P?2`I('L*("`@($!!4D=6(#T@;6%P("1%3E9[
M(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B`@
M("`D,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["B`@("!F;W(@*&ME
M>7,@)45.5BD@>PH@("`@("`@(&1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!
M4D=67R\["B`@("!]"GT*"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT[
M"@HC(&9I>"`D<')O9VYA;64@:68@:6YV;VME9"!F<F]M(%!!5$@*;7D@)4-O
M;F9I9R`]("@*("`@('!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@
M/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_
M.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*("`@(%]D96QI
M;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL
M"BD["@I?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*"B,@36%G
M:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R86-T:6YG(&)U;F1L960@;6]D
M=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*("`@(&QO
M8V%L("1324=[7U]705).7U]](#T@<W5B('M].PH*("`@(",@0VAE8VL@9FEL
M92!T>7!E+"!G970@<W1A<G0@;V8@9&%T82!S96-T:6]N('M[>PH@("`@;W!E
M;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["B`@("!B:6YM;V1E*%]&
M2"D["@H@("`@;7D@)&)U9CL*("`@('-E96L@7T9(+"`M."P@,CL*("`@(')E
M860@7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y0
M05(N<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ,BP@,CL*("`@(')E860@7T9(
M+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B
M=68I+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["@H@("`@)&1A=&%?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C('U]?0H*("`@(",@17AT<F%C=&EN
M9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@>WM["B`@("!M>2`E<F5Q=6ER95]L
M:7-T.PH@("`@=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["B`@("`@("`@<F5A
M9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PH*("`@("`@("!M>2`D9G5L;&YA;64@/2`D8G5F.PH@
M("`@("`@(&]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI
M*3L*("`@("`@("!M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<
M9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@("`@("`@(&UY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!I9B`H9&5F:6YE
M9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*
M("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H
M)&5X="P@)&-R8RD["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@
M("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@
M)&]U="`D8G5F.PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@
M("`@("`@("`@(&-H;6]D(#`W-34L("1F:6QE;F%M93L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M
M97T@/2`D9FEL96YA;64["B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*("`@("`@("!]"B`@("`@
M("`@96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I
M;F5D("1%3E9[4$%27U1%35!]("D@>PH@("`@("`@("`@("`C('-H;W5L9"!B
M92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@("`@("`@("!M>2`D9FEL96YA
M;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["B`@("`@("`@
M("`@(&]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PH@("`@("`@("`@("!O
M<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@("`@
M("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@<')I;G0@)&]U="`D
M8G5F.PH@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@('T*("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@)')E<75I<F5?;&ES='LD9G5L;&YA;65]
M(#T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL
M;F%M97T@/2!["B`@("`@("`@("`@("`@("!B=68@/3X@)&)U9BP*("`@("`@
M("`@("`@("`@(&-R8R`]/B`D8W)C+`H@("`@("`@("`@("`@("`@;F%M92`]
M/B`D9G5L;&YA;64L"B`@("`@("`@("`@('T["B`@("`@("`@?0H@("`@("`@
M(')E860@7T9(+"`D8G5F+"`T.PH@("`@?0H@("`@(R!]?7T*"B`@("!L;V-A
M;"!`24Y#(#T@*'-U8B!["B`@("`@("`@;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PH*("`@("`@("!R971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U
M;&4["@H@("`@("`@(&UY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@("`@("`@("`@;7D@)&ME>3L*("`@
M("`@("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["B`@("`@
M("`@("`@("`@("!N97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*("`@("`@
M("`@("`@("`@("1K97D@/2`D7SL@;&%S=#L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D
M*"1K97DI.PH@("`@("`@('T@;W(@<F5T=7)N.PH*("`@("`@("`D24Y#>R1M
M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PH*("`@("`@
M("!I9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ
M;F5W*2D@>PH@("`@("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M
M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@
M("`@("`@("`@('!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PH@("`@("`@
M("`@("!S965K*"1F:"P@,"P@,"D["B`@("`@("`@("`@(')E='5R;B`D9F@[
M"B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!M>2`H)&]U
M="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]
M*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I
M;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1F:6QE
M;F%M92T^>V)U9GT["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1N86UE
M(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M("`@("!R971U<FX@)&9H.PH@("`@("`@('T*"B`@("`@("`@9&EE(")";V]T
M<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["B`@
M("!]+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D(&%L;"!B=6YD;&5D(&9I;&5S
M('M[>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R960@;V)J96-T('!R;V-E<W-I
M;F<*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E(%!!4CHZ2&5A
M=GD["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R(&UO9'5L
M97,@9G)O;2!W:71H:6X*("`@(')E<75I<F4@24\Z.D9I;&4["@H@("`@(R!L
M;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@("!W:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PH@("`@("`@
M("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G
M35-7:6XS,B<["B`@("`@("`@=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@
M)&9I;&5N86UE(#U^("]"4T1004XO*2!["B`@("`@("`@("`@(",@<F5Q=6ER
M92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A8FQE(&9I;&5S"B`@("`@("`@
M("`@(&EF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PH@("`@("`@("`@
M("`@("`@<F5Q=6ER92`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS92!["B`@("`@("`@("`@("`@("`C(%-K:7`@06-T:79E4W1A
M=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z"B`@("`@("`@("`@("`@("!D
M;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ
M95PN<&PD+SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!D96QE
M=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PH@("`@?0H*("`@(",@?7U]
M"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B`@("`D
M<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*(R!]?7T*"B,@07)G=6UE
M;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U
M;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["@ID96QE=&4@)$5.5GM005)?
M05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I
M='D@<')O8FQE;2D*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'
M?3L*(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL960@97AE
M8W5T86)L97,@=VET:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O
M<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@
M>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?
M<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS
M=&%L;%]P87(*("`@("`@("!S("`@<VEG;E]P87(*("`@("`@("!V("`@=F5R
M:69Y7W!A<@H@("`@*3L*"B`@("`C(&EF('1H92!A<'`@:7,@:6YV;VME9"!A
M<R`B87!P;F%M92`M+7!A<BUO<'1I;VYS("TM<F5U<V4@4%)/1U)!32!`4%)/
M1U]!4D=6(BP*("`@(",@=7-E('1H92!A<'`@=&\@<G5N('1H92!G:79E;B!P
M97)L(&-O9&4@:6YS=&5A9"!O9B!A;GET:&EN9R!F<F]M('1H90H@("`@(R!A
M<'`@:71S96QF("AB=70@<W1I;&P@<V5T('5P('1H92!N;W)M86P@87!P(&5N
M=FER;VYM96YT(&%N9"!`24Y#*0H@("`@:68@*$!!4D=6(&%N9"`D05)'5ELP
M72!E<2`G+2UR975S92<I('L*("`@("`@("!S:&EF="!`05)'5CL*("`@("`@
M("`D14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["B`@("!]"B`@
M("!E;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*"B`@("`@("`@;7D@
M0&%D9%]T;U]I;F,["B`@("`@("`@=VAI;&4@*$!!4D=6*2!["B`@("`@("`@
M("`@("1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["@H@("`@("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@("`@("`@
M("`@("`@("!P=7-H($!A9&1?=&]?:6YC+"`D,CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@("`@("`@
M("!E=F%L(")U<V4@)#(B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L
M<VEF("@D,2!E<2`G02<I('L*("`@("`@("`@("`@("`@('5N<VAI9G0@0'!A
M<E]A<F=S+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H
M)#$@97$@)T\G*2!["B`@("`@("`@("`@("`@("`D;W5T(#T@)#(["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=B)RD@>PH@("`@
M("`@("`@("`@("`@)&)U;F1L92`]("=S:71E)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@("`@("`@
M("`D8G5N9&QE(#T@)V%L;"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96QS:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@("`@("`@("`@)'%U:65T(#T@
M,3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TPG
M*2!["B`@("`@("`@("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@
M9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@("`@("`@
M("`@("1C86-H95]N86UE(#T@)#(["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@('-H:69T*$!!4D=6*3L*"B`@("`@("`@("`@(&EF("AM>2`D8VUD(#T@
M)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@("`@("`@9&5L971E("1%3E9[
M)U!!4E]414U0)WT["B`@("`@("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@
M("`@("`@("`@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("`@("`@("`@("`@
M("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@
M("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8[
M"B`@("`@("`@("`@("`@("!E>&ET.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!U;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PH@("`@?0I]
M"@HC(%A86"`M+2!A9&0@+2UP87(M9&5B=6<@<W5P<&]R="$*"B,@?7U]"@HC
M($]U='!U="!M;V1E("@M3RD@:&%N9&QI;F<@>WM["FEF("@D;W5T*2!["B`@
M("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@
M:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($E/.CI&:6QE
M.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H*("`@(&UY
M("1P87(@/2!S:&EF="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I9B`H
M9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A
M<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@(&)I
M;FUO9&4H)&9H*3L*("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*
M("`@("`@("`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@*"`D
M>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E860@)R1P
M87(G(&5R<F]R.B`D(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R!["B`@
M("`@("`@:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H
M)TU%5$$N>6UL)RDI('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z
M)"\O;7,["B`@("`@("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@
M("`@("`@("`D;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@("`@
M("`@?0H@("`@?3L*"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U="!F:6QE
M<R![>WL*("`@(&QO8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@)'!A
M<BD@>PH@("`@("`@(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@
M)'!A<B(["B`@("`@("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B)'!A
M<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<
M,#`T(CL*("`@('T*"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@("`@
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@("`@
M($E/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\
M($E/.CI&:6QE.CI/7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@;W(@
M9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN960@
M)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@7T9(
M+"`P+"`P.PH@("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@(&EF
M("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\
M7$!R96TI+RD@>PH@("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PH@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L
M>2A<)&QO861E<BP@)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E96YV*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@
M;W(@;F5X=#L*("`@("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@
M+UY;)R)=+SL*("`@("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U
M8R@D:V5Y*2`N(")?7R(["B`@("`@("`@;7D@)'-E="`](")005)?(B`N('5C
M*"1K97DI("X@(CTD=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA9VEC
M*"`K*7U["B`@("`@("`@("`@("1M86=I8R`N("1S970@+B`H)R`G('@@*&QE
M;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@('T*
M("`@("1F:"T^<')I;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@("`@
M(R!]?7T*"B`@("`C(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@(&EF
M("@D8G5N9&QE*2!["B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@
M("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@("!I
M;FET7VEN8R@I.PH*("`@("`@("!R97%U:7)E7VUO9'5L97,H*3L*"B`@("`@
M("`@;7D@0&EN8R`]('-O<G0@>PH@("`@("`@("`@("!L96YG=&@H)&(I(#P]
M/B!L96YG=&@H)&$I"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@(2]"
M4T1004XO"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@*"1B=6YD;&4@
M;F4@)W-I=&4G*2!O<@H@("`@("`@("`@("`H)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAL:6)E>'!](&%N9`H@("`@("`@("`@("`@)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*("`@("`@("!]($!)3D,["@H@("`@
M("`@(",@1FEL92!E>&ES=',@=&5S="!A9&1E9"!T;R!F:7@@4E0@(S0Q-SDP
M.@H@("`@("`@(",@1G5N;GDL(&YO;BUE>&ES=&EN9R!E;G1R>2!I;B!?/"XN
M+BYA=71O+T-O;7!R97-S+U)A=R]:;&EB+V%U=&]S<&QI="YI>"X*("`@("`@
M("`C(%1H:7,@:7,@82!B86YD+6%I9"!F:7@@=VET:"!N;R!D965P97(@9W)A
M<W`@;V8@=&AE(&ES<W5E+@H@("`@("`@(",@4V]M96)O9'D@<&QE87-E(&=O
M('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T)W,@:&%P
M<&5N:6YG+`H@("`@("`@(",@22!F86EL960N("TM(%-T969F96X*("`@("`@
M("!M>2`E9FEL97,["B`@("`@("`@+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD
M("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S>R1?
M?2LK(&9O<B!V86QU97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D
M0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R:71T96X[
M"@H@("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@("`@
M("`@("`@;7D@*"1N86UE+"`D9FEL92D["@H@("`@("`@("`@("!F;W)E86-H
M(&UY("1D:7(@*$!I;F,I('L*("`@("`@("`@("`@("`@(&EF("@D;F%M92`]
M("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@("`@("`@
M("`@("`@)&9I;&4@/2`D7SL*("`@("`@("`@("`@("`@("`@("!L87-T.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*"]>*%Q1
M)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@("`@("`@
M("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@("`@("`@
M("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L
M<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@
M("`@("`@("`@("`@(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L
M94-A8VAE>R0Q?2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L
M("1N86UE*2`]("@D<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@
M(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!N97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[
M)&YA;65]*RL["B`@("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL92D@86YD
M("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@("!O=71S
M*"!J;VEN("(B+`H@("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F
M("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@("`@("`@
M("`@<7$H(BXN+BD*("`@("`@("`@("`@*3L*"B`@("`@("`@("`@(&UY("1C
M;VYT96YT.PH@("`@("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@
M("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!O<&5N($9)
M3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2([
M"B`@("`@("`@("`@("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@("`@("`@
M("`@)&-O;G1E;G0@/2`\1DE,13X["B`@("`@("`@("`@("`@("!C;&]S92!&
M24Q%.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@("`@("`@
M("`@(&EF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_
M.G!M?&EX?&%L*20O:3L*"B`@("`@("`@("`@("`@("`C($1O(&YO="!L970@
M6%-,;V%D97(@<&EC:R!U<"!A=71O+RH@9G)O;2!E;G9I<F]N;65N=`H@("`@
M("`@("`@("`@("`@)&-O;G1E;G0@/7X@<R]G;W1O("MR971R>2`K=6YL97-S
M("LN*B]G;W1O(')E=')Y.R\*("`@("`@("`@("`@("`@("`@("!I9B!L8R@D
M;F%M92D@97$@;&,H(EA33&]A9&5R+G!M(BD["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@("`@
M("`@("`@("1F:"T^<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H+3YP
M<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@("`@
M("`@)&9H+3YP<FEN="AS<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P.'@O
M)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N
M86UE"B`@("`@("`@("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A
M8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F:"T^
M<')I;G0H)&-O;G1E;G0I.PH@("`@("`@('T*("`@('T*("`@(",@?7U]"@H@
M("`@(R!.;W<@=W)I=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN9W,@
M>WM["B`@("`D>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`[
M"@H@("`@)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P
M.PH@("`@:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)&]U="DI6SE=*2!["B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@
M("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(
M03$M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R:V%R
M;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@
M("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI6
M15)324].('T@?'P@,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U
M+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@
M("1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@
M?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E
M;BAM>2`D9F@L("(\)&]U="(I*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E
M*"1F:"D["B`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@
M("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD
M:6=E<W0@.B`D;71I;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B
M('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*("`@("1C86-H95]N86UE
M("X](")#04-(12(["B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*("`@
M("1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A
M9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@)&9H
M+3YC;&]S93L*("`@(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*("`@
M(&5X:70["GT*(R!]?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!005(@
M9FEL92!C86-H92![>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A
M<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L;V%D
M('1H92!005(@9FEL92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H92![
M>WL*("`@(')E<75I<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PH*"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP
M;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R
M97%U:7)E($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI:
M:7`["B`@("!]"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@
M("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL
M96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ
M3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M(#T@)'II<#L*"B`@("`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH@("`@
M;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D[
M"@H@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@
M8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@("`@9F]R96%C:"!M>2`D;65M
M8F5R("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@("`@("`@;F5X="!I9B`D
M;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@("`@("`@;7D@)&UE;6)E<E]N
M86UE(#T@)&UE;6)E<BT^9FEL94YA;64["B`@("`@("`@("`@(&YE>'0@=6YL
M97-S("1M96UB97)?;F%M92`]?B!M>PH@("`@("`@("`@("`@("`@7@H@("`@
M("`@("`@("`@("`@+S]S:&QI8B\*("`@("`@("`@("`@("`@("@_.B1#;VYF
M:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@("`@("`@("`@("`@*#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`@("`@*%M>
M+UTK*0H@("`@("`@("`@("`@("`@)`H@("`@("`@("`@("!]>#L*("`@("`@
M("`@("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@("`@("`@("`@("!M>2`D
M9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0
M?2P@)&5X=')A8W1?;F%M92D["B`@("`@("`@("`@(&EF("@M9B`D9&5S=%]N
M86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2![
M"B`@("`@("`@("`@("`@("!O=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA
M;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@;W5T<RAQ
M<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI
M.PH@("`@("`@("`@("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I.PH@("`@("`@("`@("`@("`@8VAM;V0H,#4U-2P@)&1E
M<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*("`@(",@?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N
M;R!M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G92![>WL*=6YL97-S("@D4$%2
M.CI,:6)#86-H97LD<')O9VYA;65]*2!["B`@("!D:64@/#P@(BXB('5N;&5S
M<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@
M+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70H@("`@("`@
M)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@("`@)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*(R!]?7T*"G-U8B!#<F5A=&50871H('L*("`@(&UY("@D;F%M92D@/2!`
M7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(&UY("@D
M8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE
M<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE
M.CI0871H.PH@("`@"B`@("!&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N
M;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"@IS
M=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG
M?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["@H@("`@<F5Q=6ER
M92!L:6(["B`@("!R97%U:7)E($1Y;F%,;V%D97(["B`@("!R97%U:7)E(&EN
M=&5G97(["B`@("!R97%U:7)E('-T<FEC=#L*("`@(')E<75I<F4@=V%R;FEN
M9W,["B`@("!R97%U:7)E('9A<G,["B`@("!R97%U:7)E($-A<G`["B`@("!R
M97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%<G)N;SL*("`@(')E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*
M("`@(')E<75I<F4@1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@
M("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R.PH@
M("`@<F5Q=6ER92!#;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4["B`@
M("!R97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI
M8CL*("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!005([
M"B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES
M=#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@<F5Q
M=6ER92!A='1R:6)U=&5S.PH@("`@979A;"![(')E<75I<F4@0W=D('T["B`@
M("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@("`@979A;"![(')E<75I<F4@
M4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5
M;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ
M3F%M961#87!T=7)E('T["B`@("!E=F%L('L@<F5Q=6ER92!097)L24\[(')E
M<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*?0H*(R!4:&4@0R!V97)S:6]N(&]F
M('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*(R!4:&ES
M(&-O9&4@86QS;R!L:79E<R!I;B!005(Z.E-E='5P5&5M<"!A<R!S971?<&%R
M7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@
M("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.
M5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0
M("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@
M("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@
M86YD("UW("1P871H.PH@("`@("`@(&UY("1U<V5R;F%M93L*("`@("`@("!M
M>2`D<'=U:60["B`@("`@("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE<F4Z
M"B`@("`@("`@979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F
M:6YE9"`D/CM].PH*("`@("`@("!I9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I
M;DYA;64I("D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*&1E9FEN960@)'!W
M=6ED*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1P=W5I9#L*("`@("`@
M("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1%
M3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["B`@("`@
M("`@?0H@("`@("`@("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@("`@
M;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M)'5S97)N
M86UE(CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!I
M9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R
M;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N
M("1P<F]G;F%M92D["B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L(#(["B`@
M("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@("`@
M("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@("`@("`@("`@("`@('-E
M96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@("!S>7-R96%D("1F:"P@
M)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<["B`@
M("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C
M:&4M(B`N("1B=68["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("`@
M("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T
M.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@
M("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI3
M2$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H85]V97)S
M:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@
M("`@("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D
M<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@("`@("`@
M)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G
M;F%M92(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I
M.PH@("`@("`@("`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@
M)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@("`@
M("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"([
M"B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP9&ER
M.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA<W0[
M"B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T96UP9FEL
M92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L("1F
M:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X
M="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@('5N;&EN
M:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U<V@@0'1M
M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@("`@(')E
M='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["B`@
M("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*
M("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D[
M"GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M93HZ
M<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF("AD969I
M;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345]
M(#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@("`@?0H*
M("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%27U1%35!]
M(&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2![
M"B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*("`@
M(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P96X@;7D@
M)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R971U<FX@:68@
M+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N/2`D0V]N
M9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@
M?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF(&5X:7-T
M<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*
M("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*("`@
M("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PH@
M("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G;F%M
M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345]
M.PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\
M(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA:V4@4%=$
M('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@
M0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN960@)E=I
M;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@("`@
M8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#
M;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN
M:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@
M,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%
M3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@
M05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*
M("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I
M('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@
M?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@
M("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H
M(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@
M)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!
M3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@
M/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@
M("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@
M('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@
M("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R
M97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M
M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X
M<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V
M96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R
M:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N
M<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R
M7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP
M="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@
M("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]2
M13HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L
M:6YE(#$P,3(*"E]?14Y$7U\*`````1L#.\@````8````%&C__^0```#D?O__
M-`$``-1___]<`0``]'___W0!``!4@/__G`$``"2"___,`0``Q(/___0!``!T
MA/__+`(``,2&__]4`@``](;__VP"``!$A___A`(``"2(__^L`@``-(C__\0"
M```4BO__%`,``$2*__\L`P``)(O__UP#``#TC/__?`,``$2-__^<`P``=(W_
M_[0#``"4CO___`,``*28__],!```5)W__Y0$``#$G?__S`0```2>___D!```
M%``````````!>E(``7@0`1L,!PB0`0``3````!P````H9___RQ8```!"#A"/
M`D0.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=+#L@$`ZD6#CA!#C!!#BA"#B!"
M#AA"#A!"#@@````````D````;````*A]___L`````%F&!H,'CP*,!4X.0(X#
MC01J"@X(1PL`%````)0```!P?O__%0````!$#B!0#@@`)````*P```!X?O__
M40````!!#A"&`D0.&(,#1`XP`D4.&$$.$$$.""P```#4````L'[__\<!````
M00X0A@)##AB#`T0.(`.\`0X800X000X(`````````"0````$`0``4(#__YH!
M````388%@P96#L`!C@*-`XP$>0H."$0+```T````+`$``,B!__^H`````$$.
M$(8"0PX8@P-)#B!L"@X80PX000X(0PL"8PX800X00PX(`````"0```!D`0``
M0(+__U`"````68T$C`6&!H,'3@Y@CP*.`P)_"@X(2@L4````C`$``&B$__\M
M`````$0.$&0."``4````I`$``("$__]*`````$0.$`)!#@@D````O`$``+B$
M___>`````$R&`X,$3`[`0(P"`GL*#@A%"P``````%````.0!``!PA?__!0``
M````````````3````/P!``!HA?__UP$```!"#A"/`D(.&(X#0@X@C01"#BB,
M!40.,(8&20XX@P='#N`@`ET*#CA!#C!!#BA"#B!"#AA"#A!"#@A!"P`````4
M````3`(``/B&__\D```````````````L````9`(``!"'___:`````$0.$(,"
M`D$*#@A+"UD*#@A/"WP*#@A$"V$."``````<````E`(``,"'___+`0```$0.
M0`-L`0H."$@+`````!P```"T`@``<(G__T@`````1`X03PH."$4+;PX(````
M%````-0"``"@B?__(@````!$#A!=#@@`1````.P"``"XB?__$@$```!"#A".
M`D(.&(T#0@X@C`1$#BB&!4$.,(,&20YP`I8*#C!!#BA!#B!"#AA"#A!"#@A&
M"P``````3````#0#``"0BO__#`H```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.
M,(8&00XX@P=/#M"#`@-!`PH..$$.,$$.*$(.($(.&$(.$$(."$0+``!$````
MA`,``%"4__^G!````$(.$(X"1`X8C0-"#B",!$$.*(8%00XP@P9'#L`@`XP"
M"@XP00XH00X@0@X80@X00@X(2PL````T````S`,``+B8__]O`````$$.$(8"
M1`X8@P-$#B`"50H.&$$.$$$."$$+1`X81`X000X(`````!0````$!```\)C_
M_T``````1`X0=PX(`"0````<!```&)G__RL"````00X0@P)$#C`#H0$*#A!!
M#@A)"P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````__________\``````````/__________````````````
M``````````$``````````0`````````!`````````+D"`````````0``````
M``#(`@````````$`````````U`(````````!`````````-\"`````````0``
M``````#I`@````````$`````````]P(````````!``````````0#````````
M`0````````!3`P````````\`````````N@0````````=`````````+H$````
M````#`````````!H&4````````T`````````F%A```````#U_O]O`````&`"
M0```````!0````````!@"T````````8`````````P`)````````*````````
M``@%````````"P`````````8`````````!4````````````````````#````
M`````&#"8````````@````````"`!P```````!0`````````!P`````````7
M`````````.@10```````!P````````"@$4````````@`````````2```````
M```)`````````!@`````````_O__;P`````@$4```````/___V\``````@``
M``````#P__]O`````&@00```````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````HP&``````````
M``````````````````"6&4```````*890```````MAE```````#&&4``````
M`-890```````YAE```````#V&4````````8:0```````%AI````````F&D``
M`````#8:0```````1AI```````!6&D```````&8:0```````=AI```````"&
M&D```````)8:0```````IAI```````"V&D```````,8:0```````UAI`````
M``#F&D```````/8:0```````!AM````````6&T```````"8;0```````-AM`
M``````!&&T```````%8;0```````9AM```````!V&T```````(8;0```````
MEAM```````"F&T```````+8;0```````QAM```````#6&T```````.8;0```
M````]AM````````&'$```````!8<0```````)AQ````````V'$```````$8<
M0```````5AQ```````!F'$```````'8<0```````AAQ```````"6'$``````
M`*8<0```````MAQ```````#&'$```````-8<0```````YAQ```````#V'$``
M``````8=0```````%AU````````F'4```````#8=0```````1AU```````!6
M'4```````&8=0```````=AU```````"&'4```````)8=0```````IAU`````
M``"V'4```````,8=0```````UAU```````#F'4```````/8=0```````!AY`
M```````6'D```````"8>0```````-AY```````!&'D```````%8>0```````
M9AY```````!V'D```````(8>0````````````/____]X6T```````.E;````
M````1T-#.B`H1TY5*2`T+C4N,2`R,#$P,#DP-R`H4F5D($AA="`T+C4N,2TS
M*0!'0T,Z("A'3E4I(#0N-2XQ(#(P,3`P.3(T("A2960@2&%T(#0N-2XQ+30I
M```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB
M=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO
M;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT
M97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T
M;W)S`"YD=&]R<P`N:F-R`"YD>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`
M+F)S<P`N8V]M;65N=```````````````````````````````````````````
M```````````````````````````````````````````````+`````0````(`
M``````````)``````````@```````!P````````````````````!````````
M````````````$P````<````"`````````!P"0```````'`(````````@````
M````````````````!````````````````````"$````'`````@`````````\
M`D```````#P"````````)`````````````````````0`````````````````
M```T````]O__;P(`````````8`)```````!@`@```````%P`````````!0``
M```````(````````````````````/@````L````"`````````,`"0```````
MP`(```````"@"`````````8````!````"``````````8`````````$8````#
M`````@````````!@"T```````&`+````````"`4```````````````````$`
M``````````````````!.````____;P(`````````:!!```````!H$```````
M`+@`````````!0`````````"``````````(`````````6P```/[__V\"````
M`````"`10```````(!$```````"```````````8````"````"```````````
M`````````&H````$`````@````````"@$4```````*`1````````2```````
M```%``````````@`````````&`````````!T````!`````(`````````Z!%`
M``````#H$0```````(`'````````!0````P````(`````````!@`````````
M?@````$````&`````````&@90```````:!D````````8````````````````
M````!````````````````````'D````!````!@````````"`&4```````(`9
M````````$`4```````````````````0`````````$`````````"$`````0``
M``8`````````D!Y```````"0'@````````@Z```````````````````0````
M````````````````B@````$````&`````````)A80```````F%@````````.
M````````````````````!````````````````````)`````!`````@``````
M``#`6$```````,!8````````JEX``````````````````"``````````````
M``````"8`````0````(`````````;+=```````!LMP```````,P`````````
M```````````$````````````````````I@````$````"`````````#BX0```
M````.+@```````!$!```````````````````"````````````````````+``
M```!`````P``````````P&````````#`````````$```````````````````
M``@```````````````````"W`````0````,`````````$,!@```````0P```
M`````!`````````````````````(````````````````````O@````$````#
M`````````"#`8```````(,`````````(````````````````````"```````
M`````````````,,````&`````P`````````HP&```````"C`````````,`(`
M```````&``````````@`````````$`````````#,`````0````,`````````
M6,)@``````!8P@````````@````````````````````(``````````@`````
M````T0````$````#`````````&#"8```````8,(```````"8`@``````````
M````````"``````````(`````````-H````!`````P````````#XQ&``````
M`/C$````````&`````````````````````@```````````````````#@````
M"`````,`````````(,5@```````0Q0```````(`0```````````````````@
M````````````````````Y0````$````P````````````````````$,4`````
M``!8`````````````````````0`````````!``````````$````#````````
M`````````````````&C%````````[@````````````````````$`````````
(````````````
